@@ -2,7 +2,7 @@
 /**
  * Mnemo_Driver:: defines an API for implementing storage backends for Mnemo.
  *
- * Copyright 2001-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -261,7 +261,16 @@ abstract class Mnemo_Driver
                           array('action' => 'delete'), true);
             } catch (Horde_Exception $e) {
             }
+
+            // Remove tags
+            $GLOBALS['injector']->getInstance('Mnemo_Tagger')
+                ->replaceTags($uid, array(), $GLOBALS['registry']->getAuth(), 'note');
+
+            /* Tell content we removed the object */
+            $GLOBALS['injector']->getInstance('Content_Objects_Manager')
+                ->delete(array($uid), 'note');
         }
+
     }
 
     /**
@@ -291,6 +300,13 @@ abstract class Mnemo_Driver
                     'mnemo:' . $this->_notepad . ':' . $uid,
                     array('action' => 'delete'),
                     true);
+
+                $GLOBALS['injector']->getInstance('Mnemo_Tagger')
+                    ->replaceTags($uid, array(), $GLOBALS['registry']->getAuth(), 'note');
+
+                /* Tell content we removed the object */
+                $GLOBALS['injector']->getInstance('Content_Objects_Manager')
+                    ->delete(array($uid), 'note');
             }
         } catch (Horde_Exception $e) {
         }
